package com.ls11.externalcodesample.names;

import java.util.concurrent.ExecutionException;

import lotus.domino.Name;
import lotus.domino.NotesException;
import lotus.domino.Session;

import com.ls11.dominohelper.DominoExecution;
import com.ls11.dominohelper.IDominoCallable;

/**
 * Sample bean implementation that provides name information for the current Notes user
 * 
 * @author Karsten Lehmann
 */
public class CurrentUserInfo {
	private String m_abbrName;
	private String m_commonName;
	
	/**
	 * Returns the common name of the current user
	 * 
	 * @return common name
	 */
	public String getCommonName() {
		if (m_commonName==null) {
			IDominoCallable<String> callable=new IDominoCallable<String>() {

				@Override
				public String call(Session session) throws NotesException {
					Name currName=session.createName(session.getUserName());
					String commonName=currName.getCommon();
					currName.recycle();
					
					return commonName;
				}
			};
			
			try {
				m_commonName=DominoExecution.run(callable).get();
			} catch (InterruptedException e) {
				throw new RuntimeException("Could not read username info", e);
			} catch (ExecutionException e) {
				throw new RuntimeException("Could not read username info", e);
			}
			
		}
		return m_commonName;
	}
	
	/**
	 * Returns the abbreviated name of the current user
	 * 
	 * @return abbreviated name
	 */
	public String getAbbreviatedName() {
		if (m_abbrName==null) {
			IDominoCallable<String> callable=new IDominoCallable<String>() {

				@Override
				public String call(Session session) throws NotesException {
					Name currName=session.createName(session.getUserName());
					String abbrName=currName.getAbbreviated();
					currName.recycle();
					
					return abbrName;
				}
			};
			
			try {
				m_abbrName=DominoExecution.run(callable).get();
			} catch (InterruptedException e) {
				throw new RuntimeException("Could not read username info", e);
			} catch (ExecutionException e) {
				throw new RuntimeException("Could not read username info", e);
			}
		}
		return m_abbrName;
	}
	
	public String getOrganisation() {
		// TODO Auto-generated method stub
		return null;
	}
}
